@@ -13,13 +13,13 @@ namespace dichotomous {
 
 onepl::onepl() : model(model_type::onepl, ONE_PARAMETER) {}
 
-double onepl::P(std::vector<double> &theta, const optimizer_vector &parameters) {
+double onepl::P(std::vector<double> &theta, const optimizer_vector &parameters, int i ) {
 	//Initialized with gamma_k value
 	double eta = parameters(0);
 
 	//Computing dot product
-	for ( size_t i = 0; i < theta.size(); ++i )
-		eta += 1 * theta[i]; //no alpha in this model
+	for ( size_t j = 0; j < theta.size(); ++j )
+		eta += 1 * theta[j]; //no alpha in this model
 
 	double P = 1.0 / (1.0 + std::exp(-eta));
 	P = std::max(P, LOWER_BOUND_);
