@@ -13,13 +13,13 @@ namespace dichotomous {
 
 twopl::twopl() : model(model_type::twopl, TWO_PARAMETERS) {}
 
-double twopl::P(std::vector<double> &theta, const optimizer_vector &parameters) {
+double twopl::P(std::vector<double> &theta, const optimizer_vector &parameters, int i) {
 	//Initialized with gamma value
 	double eta = parameters(parameters.size() - 1);
 
 	//Computing dot product
-	for ( size_t i = 0; i < theta.size(); ++i )
-		eta += parameters(i) * theta[i];
+	for ( size_t j = 0; j < theta.size(); ++j )
+		eta += parameters(j) * theta[j];
 
 	double P = 1.0 / (1.0 + std::exp(-eta));
 	P = std::max(P, LOWER_BOUND_);
