@@ -18,7 +18,9 @@
 
 #include <iostream>
 
+#ifdef _OPENMP
 #include <omp.h>
+#endif
 
 namespace latentregpp {
 
